package com.chinaitop.depot.grainSituationCard.controller;

import com.alibaba.fastjson.JSON;
import com.chinaitop.depot.common.ResponseEntity;
import com.chinaitop.depot.grainSituationCard.model.StorageCerealsCard;
import com.chinaitop.depot.grainSituationCard.model.StorageGrainCard;
import com.chinaitop.depot.grainSituationCard.service.StorageCerealsCardService;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.List;

/**
 * @author qingsong.han
 * @description: 成品粮-粮情卡
 * @create 2020-07-13 9:33
 */
@RestController
@SuppressWarnings("all")
@RequestMapping(value = "/cerealsCard")
@Api(value = "storageCerealsCardController", description = "成品粮(粮情卡-主页)")
public class StorageCerealsCardController {
    private final static Logger logger = LoggerFactory.getLogger(StorageCerealsCardController.class);
    @Resource
    private StorageCerealsCardService cerealsCardService;

    /**
     * 选择仓房货位查询列表信息,分页.
     *
     * @param storehouseCode
     * @param warehouseCode
     * @param orgId
     * @return
     */
    @RequestMapping(value = "/getPageInfo", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value = "根据仓房号和货位号查询", notes = "查询粮情卡列表,支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "组织机构编码", defaultValue = "1", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "组织机构编码", defaultValue = "10", paramType = "query"),
            @ApiImplicitParam(name = "spareOne", value = "仓房id", paramType = "query"),
            @ApiImplicitParam(name = "spareTwo", value = "货位id", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织机构编码", paramType = "query")
    })
    public ResponseEntity getPageInfo(Integer pageNum, Integer pageSize, String spareOne, String spareTwo, String createTime, String orgId) {
        List<StorageCerealsCard> list = null;
        try {
            if (StringUtils.isBlank(orgId)) {
                return ResponseEntity.failed("组织机构编码不能为空!");
            }
            if (null != pageNum && null != pageSize) {
                PageHelper.startPage(pageNum, pageSize);
            }
            list = cerealsCardService.getList(spareOne, spareTwo, createTime, orgId);
        } catch (Exception e) {
            e.printStackTrace();
        }
        PageInfo<StorageCerealsCard> pageInfo = new PageInfo<>(list);
        return ResponseEntity.ok(pageInfo);
    }

    /**
     * 成品粮粮情卡保存
     * @param cerealsCard
     * @return
     */
    @RequestMapping(value = "/saveData", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value = "成品粮保存数据接口", notes = "成品粮保存成品粮粮情卡")
    @ApiImplicitParam(name = "cerealsCard", value = "json字符串", paramType = "query")
    public ResponseEntity saveData(String cerealsCard) {
        try {
            // 接收数据
            logger.info(cerealsCard);
            // json字符串转对象
            if (StringUtils.isNotBlank(cerealsCard)) {
                StorageCerealsCard storageCerealsCard = JSON.parseObject(cerealsCard, StorageCerealsCard.class);
                storageCerealsCard.setSfgd("1");
                cerealsCardService.saveData(storageCerealsCard);
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return ResponseEntity.ok();
    }

    /**
     * 根据id查询数据
     * @param id
     * @return
     */
    @RequestMapping(value = "/getDataById", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    public ResponseEntity getDataById(String id) {
        try {
            if (StringUtils.isBlank(id)) {
                return ResponseEntity.failed("id不能为空!");
            }
            StorageCerealsCard storageCerealsCard = cerealsCardService.findDataById(id);
            return ResponseEntity.ok(storageCerealsCard);
        } catch (Exception e) {
            e.printStackTrace();
        }
        return ResponseEntity.ok();
    }


}
