package com.chinaitop.depot.grainSituationCard.controller;

import com.chinaitop.depot.common.ResponseEntity;
import com.chinaitop.depot.grainSituationCard.model.StorageOverRunAlarmView;
import com.chinaitop.depot.grainSituationCard.service.StorageOverRunAlarmService;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.apache.commons.lang.StringUtils;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

import javax.annotation.Resource;

/**
 * 库存超限告警
 * @author aihua
 * @date 2022-04-15 21:06
 */
@RestController
@RequestMapping("/overRunAlarm")
@Api(value = "StorageGrainCardController", description = "库存超限告警-主页")
@RequiredArgsConstructor
public class StorageOverRunAlarmController {

	@Resource
    private StorageOverRunAlarmService storageOverRunAlarmService;

    @RequestMapping(value = "/getOverRunAlarmList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value = "库存超限报警查询", notes = "查询库存超限报警列表,支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "起始页", defaultValue = "1", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "页面大小", defaultValue = "10", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织机构编码", paramType = "query")
    })
    public ResponseEntity<PageInfo<StorageOverRunAlarmView>> getOverRunAlarmList(Integer pageNum, Integer pageSize, String orgId) {
        if (StringUtils.isBlank(orgId)) {
            return ResponseEntity.failed("组织机构编码不能为空!");
        }
        if (pageNum != null && pageSize != null) {
            PageHelper.startPage(pageNum, pageSize);
        }
        List<StorageOverRunAlarmView> list = storageOverRunAlarmService.getAlarmList(orgId);
        PageInfo<StorageOverRunAlarmView> pageInfo = new PageInfo<>(list);
        // 不使用sql执行分页时StartRow和EndRow使用的索引0-N,为显示效果需要索引+1.
        if (pageInfo.getTotal() > 0) {
            // 显示页加1
            pageInfo.setStartRow(pageInfo.getStartRow() + 1);
            pageInfo.setEndRow(pageInfo.getEndRow() + 1);
        }
        return ResponseEntity.ok(pageInfo);
    }
}
