package com.chinaitop.depot.grainSituationCard.controller;

import java.util.List;

import javax.annotation.Resource;

import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.chinaitop.depot.common.ResponseEntity;
import com.chinaitop.depot.grainSituationCard.model.StorageTempCard;
import com.chinaitop.depot.grainSituationCard.model.StorageWarterDetailed;
import com.chinaitop.depot.grainSituationCard.service.StorageWarterCardService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * @author guishun.lian
 * @description: 水分检验记录
 * @create 2020-07-15 10:35
 */
@RestController
@RequestMapping(value = "/WarterCard")
@Api(value = "StorageWarterCardController", description = "粮情卡-水分")
public class StorageWarterCardController {

	private final static Logger logger = LoggerFactory.getLogger(StorageWarterCardController.class);

	@Resource
	private StorageWarterCardService warterCardService;

	@RequestMapping(value = "/findWarterCardList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value = "查询原粮粮情卡下：水分检验页签数据")
	@ApiImplicitParams({
			@ApiImplicitParam(name="id", value = "粮情卡id", paramType = "query"),
			@ApiImplicitParam(name="orgId", value = "组织机构id", paramType = "query")
			})
	public ResponseEntity findWarterCardList(String id, int orgId) {
		List<StorageWarterDetailed> warterCardList = null;
		try {
			if (StringUtils.isNotBlank(id)) {
				warterCardList = warterCardService.findWarterCardList(id, orgId);
			}
			return ResponseEntity.ok(warterCardList);
		} catch (Exception e) {
			//e.printStackTrace();
			logger.error(e.getMessage(), e);
		}
		return ResponseEntity.failed("水分卡编码不能为空!");
	}

	@RequestMapping(value = "/saveWarterData", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
	@ApiOperation(value = "保存,提交接口", notes = "保存提交")
	@ApiImplicitParams({ @ApiImplicitParam(name = "addDcsls", value = "json字符串数组", paramType = "query"),
			@ApiImplicitParam(name = "flagType", value = "保存:1,提交:2", paramType = "query"),
			@ApiImplicitParam(name = "orgId", value = "组织机构编码", paramType = "query") })
	public ResponseEntity saveWarterData(String addDcsls, String flagType, int orgId, String warterRemark) {
		logger.info(addDcsls);
		// 返回语
		String str = "";
		try {
			if (StringUtils.isBlank(addDcsls)) {
				return ResponseEntity.failed("数据不能为空!");
			}
			if (StringUtils.isBlank(flagType)) {
				return ResponseEntity.failed("标识不能为空!");
			}
			// 保存:1,提交:2
			warterCardService.saveWarterData(addDcsls, flagType, orgId, warterRemark);
		} catch (Exception e) {
			logger.error(e.getMessage(), e);
		}
		return ResponseEntity.ok(str);
	}

    @RequestMapping(value = "/removeWarterData", method = RequestMethod.GET)
    @ApiOperation(value = "根据粮情卡id查询", notes = "查询质量记录")
    @ApiImplicitParams({
		 @ApiImplicitParam(name = "id", value = "主表id", paramType = "query")
	})
    public ResponseEntity deleteDailyCardById(String warterDataId) {

    	try {
			if(warterDataId != null) {
		 		warterCardService.deleteWarterCardById(warterDataId);
			}
			return ResponseEntity.failed("删除成功!");
		} catch (Exception e)  {
			 e.printStackTrace();
		}
		return ResponseEntity.failed("删除失败!");
    }
}
