package com.chinaitop.depot.grainSituationCard.service.impl;

import com.alibaba.fastjson.JSON;
import com.chinaitop.depot.common.UuidUtils;
import com.chinaitop.depot.config.DateUtil;
import com.chinaitop.depot.feign.BasicStorehouseFeignClient;
import com.chinaitop.depot.feign.BasicWarehouseFeignClient;
import com.chinaitop.depot.grainSituationCard.mapper.StorageCerealsCardMapper;
import com.chinaitop.depot.grainSituationCard.model.StorageCerealsCard;
import com.chinaitop.depot.grainSituationCard.model.StorageCerealsCardExample;
import com.chinaitop.depot.grainSituationCard.model.StorageOverRunAlarm;
import com.chinaitop.depot.grainSituationCard.service.StorageCerealsCardService;
import com.chinaitop.depot.grainSituationCard.service.StorageOverRunAlarmService;
import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;

/**
 * @author qingsong.han
 * @description:
 * @create 2020-07-13 11:18
 */
@Service
public class StorageCerealsCardServiceImpl implements StorageCerealsCardService {

    private final static Logger logger = LoggerFactory.getLogger(StorageCerealsCardService.class);

    @Resource
    private StorageCerealsCardMapper cerealsCardMapper;

    @Resource
    private BasicWarehouseFeignClient basicWarehouseFeignClient;

    @Resource
    private BasicStorehouseFeignClient basicStorehouseFeignClient;

    @Resource
    private StorageOverRunAlarmService storageOverRunAlarmService;

    /**
     * 分页列表
     *
     * @param spareOne
     * @param spareTwo
     * @param orgId
     * @return
     */
    @Override
    public List<StorageCerealsCard> getList(String spareOne, String spareTwo, String createTime, String orgId) {
        StorageCerealsCardExample example = new StorageCerealsCardExample();
        StorageCerealsCardExample.Criteria criteria = example.createCriteria();
        criteria.andOrgIdEqualTo(orgId);
        criteria.andSfgdEqualTo("1"); //默认查询未归档的粮情卡
        if (StringUtils.isNotBlank(spareOne)) {
            criteria.andSpareOneEqualTo(spareOne);
        }
        if (StringUtils.isNotBlank(spareTwo)) {
            criteria.andSpareTwoEqualTo(spareTwo);
        }
        if (StringUtils.isNotBlank(createTime)) {
            SimpleDateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
            Date date = null;
            try {
                date = dateFormat.parse(createTime);
            } catch (ParseException e) {
                e.printStackTrace();
            }
            criteria.andJkrqLessThanOrEqualTo(date);
        }
        example.setOrderByClause("jkrq desc");
        return cerealsCardMapper.selectByExample(example);
    }

    /**
     * 成品粮粮情卡保存
     *
     * @param storageCerealsCard
     */
    @Override
    public void saveData(StorageCerealsCard storageCerealsCard) {
        if (StringUtils.isNotBlank(storageCerealsCard.getId())) { // 修改
            cerealsCardMapper.updateByPrimaryKeySelective(storageCerealsCard);
        } else { // 保存
            storageCerealsCard.setId(UuidUtils.getCode());
            cerealsCardMapper.insertSelective(storageCerealsCard);

            //生成粮情卡后，将粮情卡对应的货位设置为封仓状态
            String ywlx = "0";//粮仓
            String spareOne = storageCerealsCard.getSpareOne();
            if (null == storageCerealsCard.getSpareTwo() || "".equals(storageCerealsCard.getSpareTwo())) {
            	ywlx = "1";//油罐
            	storageCerealsCard.setSpareTwo(spareOne);
            }
            updateCrkZt("3", Integer.parseInt(storageCerealsCard.getOrgId()), Integer.parseInt(storageCerealsCard.getSpareTwo()), ywlx);

            BigDecimal quantity = new BigDecimal(storageCerealsCard.getLysl());
            BigDecimal designCapacity = storageOverRunAlarmService.getStoreDesignCapacityById(Integer.parseInt(spareOne));
            // 设计仓容 < 库存数量
            if (designCapacity != null && designCapacity.compareTo(quantity) < 0) {
                logger.info("generator storage overrun alarm store house designCapacity :[{}], into store quantity :[{}]", designCapacity, quantity);
                Integer qualityId = Optional.ofNullable(cerealsCardMapper.findQuality(spareOne, storageCerealsCard.getSpareTwo(), storageCerealsCard.getOrgId())).orElse(0);
                Integer levelEnumId = Integer.parseInt(storageCerealsCard.getLydjCode());
                String level = storageOverRunAlarmService.findByEnum(levelEnumId);
                String quality = storageOverRunAlarmService.findByEnum(qualityId);

                StorageOverRunAlarm alarm = new StorageOverRunAlarm();
                alarm.setId(UuidUtils.getCode());
                alarm.setStoreHouseId(Integer.parseInt(spareOne));
                alarm.setGrainOilName(storageCerealsCard.getLypzName());
                // 粮油性质
                alarm.setGrainOilQuality(quality);
                alarm.setInventoryQuantity(quantity.multiply(new BigDecimal(1000)).toString());
                alarm.setDesignCapacity(designCapacity.toString());
                // 等级
                alarm.setLevel(level);
                alarm.setOrgId(Integer.parseInt(storageCerealsCard.getOrgId()));
                alarm.setAlarmTime(DateUtil.getNow());
                alarm.setCreateTime(DateUtil.getNow());
                storageOverRunAlarmService.insertStorageAlarm(alarm);
            }
        }
    }

    /**
	 * 修改成品粮库的出入库状态
	 * @param crk_bz 出入库状态值
	 * @param orgId 单位ID
	 * @param warehouseId 货位ID
	 * @param ywlx 1分件(粮仓),2油罐
	 */
	private void updateCrkZt(String crk_bz, Integer orgId, Integer warehouseId, String ywlx) {
		List<Map<String, Object>> wareList = new ArrayList<>();
		Map<String, Object> wareMap = new HashMap<>();
		wareMap.put("wareId", warehouseId); // 货位id
		wareMap.put("orgId", orgId); // 组织机构id
		wareMap.put("crk_status", crk_bz);
		wareMap.put("ywlx", ywlx);
		wareMap.put("lylx", "1");//这里的默认都是成品粮
		wareList.add(wareMap);
		String wareJson = JSON.toJSONString(wareList);
		basicWarehouseFeignClient.updateWarehouseCrkStatus(wareJson);
	}

    /**
     * 根据id查询数据
     * @param id
     * @return
     */
    @Override
    public StorageCerealsCard findDataById(String id) {
        return cerealsCardMapper.selectByIdJoinKeeper(id);
    }

}
