package com.chinaitop.depot.grainSituationCard.service.impl;

import com.alibaba.fastjson.JSONArray;
import com.chinaitop.depot.common.UuidUtils;
import com.chinaitop.depot.grainSituationCard.mapper.StorageTempCardMapper;
import com.chinaitop.depot.grainSituationCard.model.StorageTempCard;
import com.chinaitop.depot.grainSituationCard.model.StorageTempCardExample;
import com.chinaitop.depot.grainSituationCard.model.TPoints;
import com.chinaitop.depot.grainSituationCard.service.StorageGrainCardService;
import com.chinaitop.depot.grainSituationCard.service.StorageTempCardService;
import org.apache.commons.lang.StringUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.StringJoiner;

/**
 * @author qingsong.han
 * @description:
 * @create 2020-06-29 13:06
 */
@Service
public class StorageTempCardServiceImpl implements StorageTempCardService {
    @Resource
    private StorageTempCardMapper tempCardMapper;
    @Resource
    private StorageGrainCardService grainCardService;

    @Override
    public List<StorageTempCard> findByStorehouseAndHouse(String storehouse, String house, String orgId) {
        // 查询数据
        Map<String, String> map = new HashMap<>();
        map.put("storehouse", storehouse);
        if (StringUtils.isNotBlank(house)) {
            map.put("house", house);
        }
        map.put("orgId", orgId);
        List<StorageTempCard> byStorehouseAndHouse = tempCardMapper.findByStorehouseAndHouse(map);
        // 过滤数据
        byStorehouseAndHouse.forEach(tempCard -> {
            // 获取检测元数据
            String str = tempCard.gettPoints();
            // json字符串数组转list对象
            List<TPoints> tPoints = JSONArray.parseArray(str, TPoints.class);
            // 字符串拼接
            StringJoiner joinerMaxDot = new StringJoiner(",");
            StringJoiner joinerMinDot = new StringJoiner(",");
            tPoints.forEach(t -> {
                /*
                 * 如果指定的数与参数相等返回0
                 * 如果指定的数小于参数返回 -1
                 * 如果指定的数大于参数返回 1
                 */
                BigDecimal temp = t.getTemp(); // 元数据粮温
                // 获取最高温位置
                int i = tempCard.getMaxTemp().compareTo(temp);
                if (i == 0) {
                    joinerMaxDot.add(t.getZ() + "层-" + t.getX() + "-" + t.getY());
                }
                // 获取最低温位置
                int i1 = tempCard.getMinTemp().compareTo(temp);
                if (i1 == 0) {
                    joinerMinDot.add(t.getZ() + "层-" + t.getX() + "-" + t.getY());
                }
            });
            // 添加部位
            tempCard.setMaxDot(joinerMaxDot.toString());
            tempCard.setMinDot(joinerMinDot.toString());
        });
        return byStorehouseAndHouse;
    }

    @Override
    public List<StorageTempCard> findTempCardList(String id, String orgId, String sortFlag) {
        StorageTempCardExample tempCardExample = new StorageTempCardExample();
        StorageTempCardExample.Criteria criteria = tempCardExample.createCriteria();
        criteria.andCardNumEqualTo(id);
        criteria.andOrgIdEqualTo(orgId);
        if ("1".equals(sortFlag)) {
            tempCardExample.setOrderByClause("data_time DESC");
        }
        return tempCardMapper.selectByExample(tempCardExample);
    }

    @Override
    public void saveAndCommit(String tempCards, String flagType, String orgId) {
        List<StorageTempCard> storageTempCards = JSONArray.parseArray(tempCards, StorageTempCard.class);
        if ("2".equals(flagType)) { //保存:1,提交:2
            grainCardService.updateGainOilCardFlagType(storageTempCards.get(0).getCardNum()); // 更新卡主表flag_type(保存:1,提交:2)
        }
        storageTempCards.forEach(tempCard -> {
            if (tempCard.getDataTime() != null) { // 排除不保存提交空数据
                if ("1".equals(flagType)) { //保存:1,提交:2
                    tempCard.setFlagType("1");
                } else {
                    tempCard.setFlagType("2");
                }
                // 组织编号
                tempCard.setOrgId(orgId);
                if (StringUtils.isBlank(tempCard.getId())) {
                    tempCard.setId(UuidUtils.getCode()); // 添加id
                    tempCardMapper.insert(tempCard); // 保存
                } else {
                    // 效验已提交的数据不可以更新(保存:1,提交:2)
                    String flagType1 = tempCardMapper.selectByPrimaryKey(tempCard.getId()).getFlagType();
                    if (!"2".equals(flagType1)) {
                        // 更新
                        tempCardMapper.updateByPrimaryKeySelective(tempCard);
                    }
                }
            }
        });
    }

    /**
     * 根据id删除
     *
     * @param id
     * @return
     */
    @Override
    public int deleteTempCardById(String id) {
        int r = 0;
        // 效验已提交的数据不可以更新(保存:1,提交:2)
        String flagType1 = tempCardMapper.selectByPrimaryKey(id).getFlagType();
        if (!"2".equals(flagType1)) {
            r = tempCardMapper.deleteByPrimaryKey(id);
        }
        return r;
    }

}
